@@ -1,8 +1,9 @@
 import uuid
 from abc import ABCMeta, abstractmethod
+from copy import deepcopy
 from enum import Enum
 from functools import total_ordering
-from typing import Any, Dict, Generic, Iterable, Optional, Tuple, TypeVar, Union
+from typing import Any, Callable, Dict, Generic, Iterable, NamedTuple, Optional, Tuple, TypeVar, Union
 
 from tdm.abstract.datamodel.span import AbstractTalismanSpan
 
@@ -36,11 +37,19 @@ class FactType(str, Enum):
 
 
 FactMetadata = Dict[str, Any]
+FACT_CONFIDENCE = 'fact_confidence'
+VALUE_CONFIDENCE = 'value_confidence'
 
 _FactValue = TypeVar('_FactValue')
 _AbstractFact = TypeVar('_AbstractFact', bound='AbstractFact')
 
 
+# TODO: add Generic[_FactValue] when python >= 3.7
+class ValueWithConfidence(NamedTuple):
+    value: _FactValue
+    confidence: Optional[float]
+
+
 class AbstractFact(Generic[_FactValue], metaclass=ABCMeta):
     __slots__ = ('_id', '_mention', '_fact_type', '_status', '_type_id', '_value', '_metadata')
 
@@ -52,8 +61,8 @@ class AbstractFact(Generic[_FactValue], metaclass=ABCMeta):
         self._fact_type = fact_type
         self._status = status
         self._type_id = type_id
-        self._value = value  # subclasses must guarantee value immutability
-        self._metadata = metadata  # subclasses must guarantee metadata immutability
+        self._value = deepcopy(value)
+        self._metadata = deepcopy(metadata)
 
     @property
     def id(self) -> str:
@@ -77,7 +86,15 @@ class AbstractFact(Generic[_FactValue], metaclass=ABCMeta):
 
     @property
     def value(self) -> Union[_FactValue, Tuple[_FactValue, ...]]:
-        return self._value  # subclasses must guarantee value immutability
+        return deepcopy(self._value)
+
+    def value_with_confidence(self) -> Union[ValueWithConfidence, Tuple[ValueWithConfidence, ...], None]:
+        if not self._metadata or VALUE_CONFIDENCE not in self._metadata:
+            return None
+
+        if not isinstance(self._value, tuple):
+            return ValueWithConfidence(deepcopy(self.value), self._metadata[VALUE_CONFIDENCE])
+        return tuple(ValueWithConfidence(v, c) for v, c in zip(deepcopy(self._value), self._metadata[VALUE_CONFIDENCE]))
 
     @property
     def has_value(self) -> bool:
@@ -85,7 +102,15 @@ class AbstractFact(Generic[_FactValue], metaclass=ABCMeta):
 
     @property
     def metadata(self) -> FactMetadata:
-        return self._metadata  # subclasses must guarantee metadata immutability
+        return deepcopy(self._metadata)
+
+    @property
+    def fact_confidence(self) -> Optional[float]:
+        return self._metadata.get(FACT_CONFIDENCE) if self._metadata is not None else None
+
+    @property
+    def has_fact_confidence(self) -> bool:
+        return self.fact_confidence is not None
 
     @staticmethod
     def generate_id() -> str:
@@ -104,13 +129,42 @@ class AbstractFact(Generic[_FactValue], metaclass=ABCMeta):
     def with_changes(self: _AbstractFact, *, status: FactStatus = None, type_id: str = None,
                      value: Union[_FactValue, Tuple[_FactValue, ...]] = None,
                      mention: Tuple[AbstractTalismanSpan, ...] = None,
-                     metadata: FactMetadata = None) -> _AbstractFact:
+                     metadata: FactMetadata = None,
+                     # metadata fields
+                     fact_confidence: float = None,
+                     value_confidence: Union[float, Tuple[float, ...]] = None) -> _AbstractFact:
         pass
 
     def __repr__(self):
         return f"Fact({self._id}, {self._fact_type}, {self._status}, {self._type_id}, {self._value}, " \
                f"{self._metadata}, {self._mention})"
 
+    @staticmethod
+    def update_metadata(f: Callable[..., _AbstractFact]):
+        def check(self: _AbstractFact, *args, value: Union[_FactValue, Tuple[_FactValue, ...]] = None, metadata: FactMetadata = None,
+                  fact_confidence: float = None,
+                  value_confidence: Union[float, Tuple[float, ...]] = None,
+                  **kwargs
+                  ) -> _AbstractFact:
+            _metadata = deepcopy(metadata) if metadata else {}
+
+            if fact_confidence is not None:
+                _metadata[FACT_CONFIDENCE] = fact_confidence
+
+            if value_confidence is not None and value is not None:
+                if isinstance(value_confidence, tuple) and isinstance(value, tuple) and (len(value_confidence) == len(value)):
+                    _metadata[VALUE_CONFIDENCE] = value_confidence
+                elif not isinstance(value_confidence, tuple) and not isinstance(value, tuple):
+                    _metadata[VALUE_CONFIDENCE] = value_confidence
+                else:
+                    raise ValueError(f'value confidence length `{value_confidence}` != value length `{value}`')
+            elif self._metadata and VALUE_CONFIDENCE in self._metadata:
+                _metadata[VALUE_CONFIDENCE] = None if value is not None else self._metadata[VALUE_CONFIDENCE]
+
+            return f(self, *args, value=value, metadata=_metadata if _metadata else None, **kwargs)
+
+        return check
+
 
 _SourceFactType = TypeVar('_SourceFactType', bound=AbstractFact)
 _TargetFactType = TypeVar('_TargetFactType', bound=AbstractFact)
