@@ -33,6 +33,14 @@ class AbstractTree(metaclass=ABCMeta):
     def node(self: _AbstractTree, node_id: str) -> _AbstractTree:
         pass
 
+    @abstractmethod
+    def detached_node(self: _AbstractTree, node_id: str) -> _AbstractTree:
+        pass
+
+    @abstractmethod
+    def contain_node(self: _AbstractTree, node_id: str) -> bool:
+        pass
+
     @abstractmethod
     def pruned(self: _AbstractTree) -> _AbstractTree:
         pass
