@@ -61,7 +61,7 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
                     try:
                         node = node_cache.get(men.node_id, None)
                         if node is None:
-                            node = self._content.node(men.node_id)
+                            node = self._content.detached_node(men.node_id)
                             node_cache[men.node_id] = node
                     except ValueError:
                         raise ValueError(f"Mention {men} facts {fact} does not apply to this document")
@@ -96,7 +96,7 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
                 yield fact
 
     def fact_text(self, fact: AbstractFact, separator: str = ' ') -> Optional[str]:
-        return separator.join(self._content.text_for(mention) for mention in fact.mention) if fact.mention else None
+        return separator.join(self.fact_text_mention(fact) or []) or None
 
     @staticmethod
     def _normalize_facts(facts: Iterable[AbstractFact]) -> FrozenSet[AbstractFact]:
@@ -183,7 +183,7 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
             directive = directives[0]
             ids = set(map(attrgetter('id'), directives[1:]))
             ret_directives.append(directive)
-            for fact in self.filter_facts(ConceptFact, lambda f: f.value in ids):
+            for fact in self.filter_facts(ConceptFact, lambda f: f.value in ids):  # noqa: B023
                 ret_facts.append(fact.with_changes(value=directive.id))
 
         return type(self)(doc_id=self._doc_id, content=self._content, metadata=self._metadata, facts=self._facts,
