@@ -2,10 +2,10 @@ __all__ = [
     'ACCOUNT_CONCEPT', 'PLATFORM_CONCEPT', 'ConceptFact',
     'ACCOUNT_NAME', 'ACCOUNT_URL', 'PLATFORM_NAME', 'PLATFORM_TYPE', 'PLATFORM_URL', 'PropertyFact', 'PropertyLinkValue',
     'ACCOUNT_PLATFORM', 'RelationFact', 'RelationLinkValue',
-    'ValueFact'
+    'PLATFORM_VALUE', 'ValueFact'
 ]
 
 from .concept import ACCOUNT_CONCEPT, ConceptFact, PLATFORM_CONCEPT
 from .property import ACCOUNT_NAME, ACCOUNT_URL, PLATFORM_NAME, PLATFORM_TYPE, PLATFORM_URL, PropertyFact, PropertyLinkValue
 from .relation import ACCOUNT_PLATFORM, RelationFact, RelationLinkValue
-from .value import ValueFact
+from .value import PLATFORM_VALUE, ValueFact
