@@ -40,10 +40,20 @@ class TreeNode(AbstractTree):
         if node_id == self._id:
             return self
         for i, node in enumerate(self._nodes):
-            if node_id in node._id2node:
+            if node.contain_node(node_id):
                 return node._with_changes(parent_func=self._parent_func_factory(i)).node(node_id)
         raise ValueError(f"Node {self._id} contains no {node_id} node")
 
+    def detached_node(self: _TreeNode, node_id: str) -> _TreeNode:
+        """This method is only valid for reading node information, not for changes. In addition, the obtained node does not contain the
+        latest information about its parent node"""
+        if self.contain_node(node_id):
+            return self._id2node[node_id]
+        raise ValueError(f"Node {self._id} contains no {node_id} node")
+
+    def contain_node(self: _TreeNode, node_id: str) -> bool:
+        return node_id in self._id2node
+
     def pruned(self: _TreeNode) -> _TreeNode:
         return self._with_changes(nodes=None)
 
