@@ -1,14 +1,13 @@
 __all__ = [
     'NodeMarkup', 'NodeMetadata', 'TreeDocumentContentModel',
-    'TalismanDocumentModel',
+    'DocumentMetadataModel', 'TalismanDocumentModel',
     'ConceptFactModel', 'PropertyFactModel', 'PropertyLinkValueModel', 'RelationFactModel', 'SpanModel', 'ValueFactModel',
     'build_fact_model',
-    'DocumentMetadataModel',
     'FactMetadataModel'
 ]
 
 from .content import NodeMarkup, NodeMetadata, TreeDocumentContentModel
-from .document import TalismanDocumentModel
+from .document import DocumentMetadataModel, TalismanDocumentModel
 from .fact import ConceptFactModel, PropertyFactModel, PropertyLinkValueModel, RelationFactModel, SpanModel, ValueFactModel, \
     build_fact_model
-from .metadata import DocumentMetadataModel, FactMetadataModel
+from .fact.common import FactMetadataModel
