@@ -11,6 +11,7 @@ class CreateConceptDirectiveModel(AbstractDirectiveModel):
     id: str
     name: str
     concept_type: str
+    filters: Tuple[dict, ...]
     notes: Optional[str]
     markers: Optional[Tuple[str, ...]]
     access_level: Optional[str]
@@ -23,6 +24,7 @@ class CreateConceptDirectiveModel(AbstractDirectiveModel):
             id=directive.id,
             name=directive.name,
             concept_type=directive.concept_type,
+            filters=directive.filters,
             notes=directive.notes,
             markers=directive.markers,
             access_level=directive.access_level
@@ -32,6 +34,7 @@ class CreateConceptDirectiveModel(AbstractDirectiveModel):
         return CreateConceptDirective(
             name=self.name,
             concept_type=self.concept_type,
+            filters=self.filters,
             notes=self.notes,
             markers=self.markers,
             access_level=self.access_level,
